#!/bin/bash
#set -x
#echo example of use : optim-example.sh cpu cpuinit.fis "3 6 2 4 1 5" 0.05 0.1

# set parameters
# initialfis is not created in this script, must be provided, for instance running:
# ols cpu -q11 -ccpuinit.fis
# which builds a 10 rule FIS

data="$1"
initialfis="$2"
order="$3"
covloss="$4"
muth="$5"
gaussr=0.005
iterin=100

echo 'data' $1
echo 'initialfis' $2
echo 'order' $3
echo 'covloss' $4
echo 'muth' $5
echo 'gauss amplitude' $gaussr
echo 'input iterations' $iterin

# generate 20 samples (10 pairs) from data set given in first parameter
ns=10
nsa=`expr $ns + $ns`
sample $data -n$nsa
# the samples are called $data.lrn.sample.0 ...$data.lrn.sample.9
# and                    $data.tst.sample.0 ...$data.tst.sample.9


kk=0
# optimization loop on samples starting with initialfis
# FIS tuning is done using each sample learning file
# performance is computed for learning and test files


while [ $kk -lt $ns ]
do
# compute initial FIS performance on test and learning samples

  perf $initialfis $data.tst.sample.$kk -s$muth
  mv perf.res perf.tst.sample$kk.res
  perf $initialfis $data.lrn.sample.$kk -s$muth
  mv perf.res perf.lrn.sample$kk.res

# optimize initial FIS
echo optimizing $initialfis inputs and rules for sample $data.lrn.sample.$kk
loopoptim $initialfis $data.lrn.sample.$kk optimfis-sample$kk $iterin $gaussr 1000 1000 0.000001 -in "$order" -r -m $muth -c $covloss

# compute optimized FIS performance on test and learning samples
  perf optimfis-sample$kk-final.fis $data.tst.sample.$kk -s$muth
  mv perf.res perf.tst.sample$kk-optim.res
  perf optimfis-sample$kk-final.fis $data.lrn.sample.$kk -s$muth
  mv perf.res perf.lrn.sample$kk-optim.res
  kk=`expr $kk + 1`
done

# results for initialfis are in perf.lrn.sample.0.res ...perf.lrn.sample.9.res
# and            perf.tst.sample.0.res ...perf.tst.sample.9.res
# results for optimizedfis are in perf.lrn.sample.0-optim.res ...perf.lrn.sample.9-optim.res
# and            perf.tst.sample.0-optim.res ...perf.tst.sample.9-optim.res

# performance files are ready for further analysis